@@ -1,12 +1,12 @@
 # Importing all balancers from modules.
 from .ADASYN import ADASYN
-from .ICOTE import ImmuneCentroidsOversampling
-from .MTDF import MegaTrendDifussionFunction
-from .MWMOTE import MajorityWeightedMinorityOversamplingTechnique, index
+from .ICOTE import ICOTE
+from .MTDF import MTDF
+from .MWMOTE import MWMOTE, index
 from .SCUT import SCUT
 from .SLS import SLS
 from .SMOTE import SMOTE
 from .SMOTEENN import SMOTEENN
 from .SMOTENC import SMOTENC
 from .SMOTETOMEK import SMOTETOMEK
-from .TKRKNN import TopKReverseKNN
+from .TKRKNN import TKRKNN
